@@ -1,9 +1,9 @@
 package ArrayDataRole::Spec::Basic;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-20'; # DATE
+our $DATE = '2021-05-03'; # DATE
 our $DIST = 'ArrayData'; # DIST
-our $VERSION = '0.2.0'; # VERSION
+our $VERSION = '0.2.1'; # VERSION
 
 use Role::Tiny;
 use Role::Tiny::With;
@@ -13,6 +13,7 @@ requires 'new';
 
 # mixin
 with 'Role::TinyCommons::Iterator::Resettable';
+with 'Role::TinyCommons::Collection::GetItemByPos';
 
 ###
 
@@ -31,20 +32,21 @@ ArrayDataRole::Spec::Basic - Required methods for all ArrayData::* modules
 
 =head1 VERSION
 
-This document describes version 0.2.0 of ArrayDataRole::Spec::Basic (from Perl distribution ArrayData), released on 2021-04-20.
+This document describes version 0.2.1 of ArrayDataRole::Spec::Basic (from Perl distribution ArrayData), released on 2021-05-03.
 
 =head1 DESCRIPTION
 
-The basic interface of an ArrayData module is a resettable iterator
-(L<Role::TinyCommons::Iterator::Resettable>). You can call L</reset_iterator> to
-jump to the first element, then call L</get_next_item> repeatedly
-to get elements one at a time until all the elements are retrieved. If you need
-to go back to the first element, you can call L</reset_iterator> again.
+L<ArrayData>::* modules let you iterate elements using a resettable iterator
+interface (L<Role::TinyCommons::Iterator::Resettable>) as well as get elements
+by position (L<Role::TinyCommons::Collection::GetItemByPos>), like what a
+regular Perl array lets you.
 
 =head1 ROLES MIXED IN
 
 L<Role::TinyCommons::Iterator::Resettable>
 
+L<Role::TinyCommons::Collection::GetItemByPos>
+
 =head1 REQUIRED METHODS
 
 =head2 new
@@ -55,9 +57,29 @@ Usage:
 
 Constructor. Must accept a pair of argument names and values.
 
+=head2 get_next_item
+
+From L<Role::TinyCommons::Iterator::Resettable>.
+
+=head2 has_next_item
+
+From L<Role::TinyCommons::Iterator::Resettable>.
+
+=head2 reset_iterator
+
+From L<Role::TinyCommons::Iterator::Resettable>.
+
+=head2 get_item_at_pos
+
+From L<Role::TinyCommons::Iterator::GetItemByPos>.
+
+=head2 has_item_at_pos
+
+From L<Role::TinyCommons::Iterator::GetItemByPos>.
+
 =head1 PROVIDED METHODS
 
-No additional provided methods.
+No additional provided methods. See from mixed-in roles.
 
 =head1 HOMEPAGE
 
@@ -79,6 +101,8 @@ feature.
 
 L<Role::TinyCommons::Iterator::Resettable>
 
+L<Role::TinyCommons::Collection::GetItemByPos>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
